% =========================================================================
%> @file  NetStyle.m
%> @author		Christian Campestrini (c.campestrini@tum.de)
%> @brief		Styles the benchmark plots
%>
%> @date		08.06.2016
%>
%> @param		handles (figure handle)
%> @param		Setup (plot setup and style information)
%> @param		FNrAlgo (list of tested algorithms)
%>
%> @retval		handles (figure handles)
%>
%> @syntax		handles=NetStyle(handles,Setup,FNrAlgo);     
% =========================================================================
function handles=NetStyle(handles,Setup,FNrAlgo)
    %% Add here your individual styling
    
    %% Set sub figure size and position
    handles.Plot{1,1}.SubP.Position(1)= 0;   
    handles.Plot{1,1}.SubP.Position(2)= 0.63;  
    handles.Plot{1,1}.SubP.Position(3)= 1;    
    handles.Plot{1,1}.SubP.Position(4)= 0.37;
    
    handles.Plot{1,2}.SubP.Position(1)= 0;   
    handles.Plot{1,2}.SubP.Position(2)= 0.3;  
    handles.Plot{1,2}.SubP.Position(3)= 1;    
    handles.Plot{1,2}.SubP.Position(4)= 0.37;
    
    handles.Plot{1,3}.SubP.Position(1)= 0;   
    handles.Plot{1,3}.SubP.Position(2)= -0.03;  
    handles.Plot{1,3}.SubP.Position(3)= 1;    
    handles.Plot{1,3}.SubP.Position(4)= 0.37;
    
    % build legend
    index=strfind(FNrAlgo,'_');
    for i=1:length(FNrAlgo)
        Ltext{i}=FNrAlgo{i}(1:index{i}-1);
    end
    
    % plot and format legend
    [handles.Plot{1,1}.Legend.h, handles.Plot{1,1}.Legend.icons,~,handles.Plot{1,1}.Legend.text]=legend(handles.Plot{1,1}.Obj,Ltext);
    
    set(handles.Plot{1,1}.Legend.h,...
        'FontSize', Setup.FontSize,...
        'FontName',Setup.FontName);

    % Plot axes names
    annotation('textbox',[0.16 0.96 0 0],'String',{'$\bar{K}_{\mathrm{trans}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0.46 0.96 1 0],'String',{'$\bar{K}_{\mathrm{res}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0 0.82 0 0],'String',{'$\bar{K}_{\mathrm{drift}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0.63 0.84 0 0],'String',{'$\bar{K}_{\mathrm{est}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0.16 0.7 1 0],'String',{'$\bar{K}_{\mathrm{fail}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0.46 0.7 1 0],'String',{'$\bar{K}_{\mathrm{temp}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');

    annotation('textbox',[0.16 0.63 0 0],'String',{'$\bar{K}_{\mathrm{trans}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0.46 0.63 1 0],'String',{'$\bar{K}_{\mathrm{res}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0 0.49 0 0],'String',{'$\bar{K}_{\mathrm{drift}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0.63 0.51 0 0],'String',{'$\bar{K}_{\mathrm{est}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0.16 0.37 1 0],'String',{'$\bar{K}_{\mathrm{fail}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0.46 0.37 1 0],'String',{'$\bar{K}_{\mathrm{temp}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');

    annotation('textbox',[0.31 0.32 1 0],'String',{'$\bar{K}_{\mathrm{res}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0 0.16 0 0],'String',{'$\bar{K}_{\mathrm{drift}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0.63 0.18 0 0],'String',{'$\bar{K}_{\mathrm{est}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
    annotation('textbox',[0.31 0.025 1 0],'String',{'$\bar{K}_{\mathrm{fail}}$'},'LineStyle','none','FontSize',Setup.FontSize,'FontName',Setup.FontName,'interpreter','latex');
  
end