% =========================================================================
%> @file  main.m
%> @author		Christian Campestrini (c.campestrini@tum.de)
%> @brief		Calculates the benchmark according to:
%>              Campestrini, C.; Horsche, M.F.; Zilberman, I.; Heil, T.;
%>              Zimmermann, T.; Jossen, A.: Validation and benchmark
%>              methods for battery management system functionalities -
%>              State of charge estimation algorithms
%>              In: Journal of Energy Storage 7, S. 3851, 2016
%>
%> @date		08.06.2016
% =========================================================================
clc
clear all
close all

addpath([pwd '\Functions'])
addpath([pwd '\Example'])   % Add folder to use the example

%% Set save path and figure options
Setup.Path=[pwd '\Results\'];       % Path
Setup.SaveFigures=1;                % Save figures 1-yes / 0-no
Setup.FigureName='NetDiagramm';     % Set figure and file name
Setup.FontName='Times New Roman';   % Set font
Setup.FontSize=9.5;                 % Set font size

%% Convert your result data to the specified format (see manual). This function is to adapt to your Data.
FilterResult=PrepResultData();

%% Set start and end points of the constant charge and discharge periods of profile A. This function is to adapt to your Data. You can also set the time manually
ProfileTiming=ProfileDataTiming();

%% Input Data Check if your data is complete 
InputDataCheck(FilterResult);

%% Benchmark calculation
Benchmark(Setup,FilterResult,ProfileTiming);
